==> vlc-0.9.9a.tar.bz2: vlc-0.9.9a/modules/gui/qt4/components/playlist/selector.cpp <==
/*****************************************************************************
 * selector.cpp : Playlist source selector
 ****************************************************************************
 * Copyright (C) 2000-2005 the VideoLAN team
 * $Id: e4b1c8269019166624b897da7fdaf8f8c62861ec $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "components/playlist/selector.hpp"
#include "qt4.hpp"

#include <QVBoxLayout>
#include <QHeaderView>
#include <QTreeView>

PLSelector::PLSelector( QWidget *p, intf_thread_t *_p_intf,
                        playlist_t *p_playlist ) : QWidget( p ), p_intf(_p_intf)
{
    model = new PLModel( THEPL, p_intf, THEPL->p_root_category, 1, this );
    view = new QTreeView( 0 );
    view->setIconSize( QSize( 24,24 ) );
    view->setAlternatingRowColors( true );
    view->setIndentation( 0 );
    view->header()->hide();
    view->setModel( model );

    view->setAcceptDrops(true);
    view->setDropIndicatorShown(true);

    CONNECT( view, activated( const QModelIndex& ),
             this, setSource( const QModelIndex& ) );
    CONNECT( view, clicked( const QModelIndex& ),
             this, setSource( const QModelIndex& ) );

    QVBoxLayout *layout = new QVBoxLayout();
    layout->setSpacing( 0 ); layout->setMargin( 0 );
    layout->addWidget( view );
    setLayout( layout );

    /* select the first item */
    view->setCurrentIndex( model->index( 0, 0, QModelIndex() ) );
}

void PLSelector::setSource( const QModelIndex &index )
{
    if( model )
        emit activated( model->itemId( index ) );
}

PLSelector::~PLSelector()
{
}

==> vlc-1.0.2.tar.bz2: vlc-1.0.2/modules/gui/qt4/components/playlist/selector.cpp <==
/*****************************************************************************
 * selector.cpp : Playlist source selector
 ****************************************************************************
 * Copyright (C) 2000-2005 the VideoLAN team
 * $Id: 22cad94f6be000d629566cb1e2c59c47c34246f9 $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "components/playlist/selector.hpp"
#include "qt4.hpp"

#include <QVBoxLayout>
#include <QHeaderView>
#include <QTreeView>

PLSelector::PLSelector( QWidget *p, intf_thread_t *_p_intf ) : QWidget( p ), p_intf(_p_intf)
{
    model = new PLModel( THEPL, p_intf, THEPL->p_root_category, 1, this );
    view = new QTreeView( 0 );
    view->setIconSize( QSize( 24,24 ) );
    view->setAlternatingRowColors( true );
    view->setIndentation( 0 );
    view->header()->hide();
    view->setModel( model );

    view->setAcceptDrops(true);
    view->setDropIndicatorShown(true);

    CONNECT( view, activated( const QModelIndex& ),
             this, setSource( const QModelIndex& ) );
    CONNECT( view, clicked( const QModelIndex& ),
             this, setSource( const QModelIndex& ) );

    QVBoxLayout *layout = new QVBoxLayout();
    layout->setSpacing( 0 ); layout->setMargin( 0 );
    layout->addWidget( view );
    setLayout( layout );

    /* select the first item */
    view->setCurrentIndex( model->index( 0, 0, QModelIndex() ) );
}

void PLSelector::setSource( const QModelIndex &index )
{
    if( model )
        emit activated( model->itemId( index ) );
}

PLSelector::~PLSelector()
{
}
